============================
Salt 2014.1.12 Release Notes
============================

:release: 2014-10-08

Version 2014.1.12 is another bugfix release for :doc:`2014.1.0
</topics/releases/2014.1.0>`.  Changes include:

- Fix ``scp_file`` always failing (which broke salt-cloud) (:issue:`16437`)
- Fix regression in pillar in masterless (:issue:`16210`, :issue:`16416`,
  :issue:`16428`)